@@ -1,6 +1,7 @@
 import abc
 from typing import *
 
+
 class ScpiTypeBase(object):
     """Base class for SCPI types"""
     __metaclass__ = abc.ABCMeta
@@ -11,7 +12,7 @@ class ScpiTypeBase(object):
         raise NotImplementedError("Please Implement this method")
 
     @abc.abstractmethod
-    def format(self) -> str:
+    def compose(self) -> str:
         """Converts the given data into SCPI "Device listening" format"""
         raise NotImplementedError("Please Implement this method")
 
@@ -19,4 +20,8 @@ class ScpiTypeBase(object):
     @abc.abstractmethod
     def parse(cls, stream):
         """Parses SCPI "Device talking Elements" into an internal representation"""
-        raise NotImplementedError("Please Implement this method")
\ No newline at end of file
+        raise NotImplementedError("Please Implement this method")
+
+
+# TypeVar for type hinting subclasses of ScpiTypeBase
+ScpiTypes = TypeVar('ScpiTypes', bound=ScpiTypeBase)
