@@ -143,17 +143,20 @@ class ScpiNumberArray(ScpiTypeBase):
     @classmethod
     def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiNumber` object"""
+        array = []
         data = transport.readline()
-        substrs = data.split(',')
 
-        try:
-            # Try as NR1 representation first
-            array = [int(substr) for substr in substrs]
-        except ValueError:
+        if len(data) > 0:
+            substrs = data.split(',')
+
             try:
-                array = [float(substr) for substr in substrs]
+                # Try as NR1 representation first
+                array = [int(substr) for substr in substrs]
             except ValueError:
-                raise TypeError
+                try:
+                    array = [float(substr) for substr in substrs]
+                except ValueError:
+                    raise TypeError
 
         return ScpiNumberArray(array)
 
@@ -189,7 +192,7 @@ class ScpiString(ScpiTypeBase):
 
     def compose(self) -> str:
         """Composes the object into a SCPI string to be used as a parameter"""
-        raise NotImplementedError
+        return f'"{self._data}"'
 
     @classmethod
     def parse(cls, transport: ScpiTransports):
